#version 120

uniform vec2 size;
uniform vec4 round;
uniform vec4 color1;
uniform vec4 color2;
uniform vec4 color3;
uniform vec4 color4;
uniform float outlineWidth;

varying vec2 fragCoord;

float roundSDF(vec2 p, vec2 b, vec4 r) {
    p = abs(p) - b;
    vec2 q = p + r.xy;
    float k = max(r.x, r.y);
    return length(max(q, 0.0)) - k;
}

void main() {
    vec2 pixel = fragCoord * size;
    vec2 center = size * 0.5;
    vec2 halfSize = size / 2.0 - vec2(outlineWidth / 2.0);
    float rounded = roundSDF(center - pixel, halfSize - vec2(outlineWidth / 2.0), round);

    vec4 color = mix(mix(color1, color2, fragCoord.x),
                     mix(color3, color4, fragCoord.x),
                     fragCoord.y);

    float smoothAlpha = smoothstep(0.0, outlineWidth / 2.0, abs(rounded) - outlineWidth / 2.0 / 2.0);

    vec4 c = mix(vec4(color.rgb, 1.0), vec4(color.rgb, 0.0), smoothAlpha);

    gl_FragColor = vec4(c.rgb, color.a * c.a);
}